syntax = "proto3";
package sarus_data_spec;

message Status {// Current form of the dataset
  string uuid = 1;
  string dataset = 2;
  string manager = 3;
  string datetime = 4; // ISO 8601 datetime
  string task = 5;
  Stage stage = 6;
  map<string, string> properties = 7; // Other properties

  message Stage {
    oneof stage {
      Pending pending = 1;
      Processing processing = 2;
      Ready ready = 3;
      Error error = 4;
    }

    message Pending {

    }

    message Processing {

    }

    message Ready {

    }

    message Error {

    }
  }
}
