# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sarus_data_spec/protobuf/scalar.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sarus_data_spec/protobuf/scalar.proto',
  package='sarus_data_spec',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%sarus_data_spec/protobuf/scalar.proto\x12\x0fsarus_data_spec\"\xa5\x05\n\x06Scalar\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12*\n\x04spec\x18\x04 \x01(\x0b\x32\x1c.sarus_data_spec.Scalar.Spec\x12;\n\nproperties\x18\x05 \x03(\x0b\x32\'.sarus_data_spec.Scalar.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1az\n\x04Spec\x12:\n\x0btransformed\x18\x01 \x01(\x0b\x32#.sarus_data_spec.Scalar.TransformedH\x00\x12.\n\x05model\x18\x02 \x01(\x0b\x32\x1d.sarus_data_spec.Scalar.ModelH\x00\x42\x06\n\x04spec\x1a\xbc\x01\n\x0bTransformed\x12\x11\n\ttransform\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x12P\n\x0fnamed_arguments\x18\x03 \x03(\x0b\x32\x37.sarus_data_spec.Scalar.Transformed.NamedArgumentsEntry\x1a\x35\n\x13NamedArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x9a\x01\n\x05Model\x12\x11\n\targuments\x18\x01 \x01(\x0c\x12\x17\n\x0fnamed_arguments\x18\x02 \x01(\x0c\x12=\n\x0bmodel_class\x18\x03 \x01(\x0e\x32(.sarus_data_spec.Scalar.Model.ModelClass\"&\n\nModelClass\x12\x0c\n\x08TF_KERAS\x10\x00\x12\n\n\x06SK_SVC\x10\x01\x62\x06proto3'
)



_SCALAR_MODEL_MODELCLASS = _descriptor.EnumDescriptor(
  name='ModelClass',
  full_name='sarus_data_spec.Scalar.Model.ModelClass',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TF_KERAS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SK_SVC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=698,
  serialized_end=736,
)
_sym_db.RegisterEnumDescriptor(_SCALAR_MODEL_MODELCLASS)


_SCALAR_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='sarus_data_spec.Scalar.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Scalar.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Scalar.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=264,
)

_SCALAR_SPEC = _descriptor.Descriptor(
  name='Spec',
  full_name='sarus_data_spec.Scalar.Spec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformed', full_name='sarus_data_spec.Scalar.Spec.transformed', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='sarus_data_spec.Scalar.Spec.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='sarus_data_spec.Scalar.Spec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=266,
  serialized_end=388,
)

_SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY = _descriptor.Descriptor(
  name='NamedArgumentsEntry',
  full_name='sarus_data_spec.Scalar.Transformed.NamedArgumentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Scalar.Transformed.NamedArgumentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Scalar.Transformed.NamedArgumentsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=579,
)

_SCALAR_TRANSFORMED = _descriptor.Descriptor(
  name='Transformed',
  full_name='sarus_data_spec.Scalar.Transformed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transform', full_name='sarus_data_spec.Scalar.Transformed.transform', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='sarus_data_spec.Scalar.Transformed.arguments', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_arguments', full_name='sarus_data_spec.Scalar.Transformed.named_arguments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=579,
)

_SCALAR_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='sarus_data_spec.Scalar.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arguments', full_name='sarus_data_spec.Scalar.Model.arguments', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_arguments', full_name='sarus_data_spec.Scalar.Model.named_arguments', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_class', full_name='sarus_data_spec.Scalar.Model.model_class', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCALAR_MODEL_MODELCLASS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=736,
)

_SCALAR = _descriptor.Descriptor(
  name='Scalar',
  full_name='sarus_data_spec.Scalar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='sarus_data_spec.Scalar.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sarus_data_spec.Scalar.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='sarus_data_spec.Scalar.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='sarus_data_spec.Scalar.spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='sarus_data_spec.Scalar.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALAR_PROPERTIESENTRY, _SCALAR_SPEC, _SCALAR_TRANSFORMED, _SCALAR_MODEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=736,
)

_SCALAR_PROPERTIESENTRY.containing_type = _SCALAR
_SCALAR_SPEC.fields_by_name['transformed'].message_type = _SCALAR_TRANSFORMED
_SCALAR_SPEC.fields_by_name['model'].message_type = _SCALAR_MODEL
_SCALAR_SPEC.containing_type = _SCALAR
_SCALAR_SPEC.oneofs_by_name['spec'].fields.append(
  _SCALAR_SPEC.fields_by_name['transformed'])
_SCALAR_SPEC.fields_by_name['transformed'].containing_oneof = _SCALAR_SPEC.oneofs_by_name['spec']
_SCALAR_SPEC.oneofs_by_name['spec'].fields.append(
  _SCALAR_SPEC.fields_by_name['model'])
_SCALAR_SPEC.fields_by_name['model'].containing_oneof = _SCALAR_SPEC.oneofs_by_name['spec']
_SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY.containing_type = _SCALAR_TRANSFORMED
_SCALAR_TRANSFORMED.fields_by_name['named_arguments'].message_type = _SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY
_SCALAR_TRANSFORMED.containing_type = _SCALAR
_SCALAR_MODEL.fields_by_name['model_class'].enum_type = _SCALAR_MODEL_MODELCLASS
_SCALAR_MODEL.containing_type = _SCALAR
_SCALAR_MODEL_MODELCLASS.containing_type = _SCALAR_MODEL
_SCALAR.fields_by_name['spec'].message_type = _SCALAR_SPEC
_SCALAR.fields_by_name['properties'].message_type = _SCALAR_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['Scalar'] = _SCALAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scalar = _reflection.GeneratedProtocolMessageType('Scalar', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCALAR_PROPERTIESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar.PropertiesEntry)
    })
  ,

  'Spec' : _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
    'DESCRIPTOR' : _SCALAR_SPEC,
    '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar.Spec)
    })
  ,

  'Transformed' : _reflection.GeneratedProtocolMessageType('Transformed', (_message.Message,), {

    'NamedArgumentsEntry' : _reflection.GeneratedProtocolMessageType('NamedArgumentsEntry', (_message.Message,), {
      'DESCRIPTOR' : _SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY,
      '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar.Transformed.NamedArgumentsEntry)
      })
    ,
    'DESCRIPTOR' : _SCALAR_TRANSFORMED,
    '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar.Transformed)
    })
  ,

  'Model' : _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), {
    'DESCRIPTOR' : _SCALAR_MODEL,
    '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar.Model)
    })
  ,
  'DESCRIPTOR' : _SCALAR,
  '__module__' : 'sarus_data_spec.protobuf.scalar_pb2'
  # @@protoc_insertion_point(class_scope:sarus_data_spec.Scalar)
  })
_sym_db.RegisterMessage(Scalar)
_sym_db.RegisterMessage(Scalar.PropertiesEntry)
_sym_db.RegisterMessage(Scalar.Spec)
_sym_db.RegisterMessage(Scalar.Transformed)
_sym_db.RegisterMessage(Scalar.Transformed.NamedArgumentsEntry)
_sym_db.RegisterMessage(Scalar.Model)


_SCALAR_PROPERTIESENTRY._options = None
_SCALAR_TRANSFORMED_NAMEDARGUMENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)
